@@ -304,7 +304,7 @@ def is_abs_url(url):
         r'(?:/?|[/?]\S+)$', re.IGNORECASE)
 
     c_regex = re.compile(regex)
-    return (c_regex.search(url) is not None)
+    return c_regex.search(url) is not None
 
 
 def b64_encode(url):
@@ -321,3 +321,15 @@ def extract_domain(url):
     tld_dat = tldextract.extract(url)
     subd = tld_dat.subdomain
     return tld_dat.domain.lower(), subd
+
+
+def is_url(url):
+    regex = re.compile(
+            r'^(?:http|ftp)s?://' # http:// or https://
+            r'(?:(?:[A-Z0-9](?:[A-Z0-9-]{0,61}[A-Z0-9])?\.)+(?:[A-Z]{2,6}\.?|[A-Z0-9-]{2,}\.?)|' #domain...
+            r'localhost|' #localhost...
+            r'\d{1,3}\.\d{1,3}\.\d{1,3}\.\d{1,3})' # ...or ip
+            r'(?::\d+)?' # optional port
+            r'(?:/?|[/?]\S+)$', re.IGNORECASE)
+
+    return re.match(regex, url) is not None
\ No newline at end of file
